@@ -412,10 +412,10 @@ def create_text_box(
     disabled_background_color = "#2d2d2d",
     disabled_border_width = 2,
     disabled_border_color = "#4a4a4a",
-    show_text_icon_url = resource_path("gui_utilities/icons/show_text_icon.png"),
-    hide_text_icon_url = resource_path("gui_utilities/icons/hide_text_icon.png"),
-    focused_show_text_icon_url = resource_path("gui_utilities/icons/focused_show_text_icon.png"),
-    focused_hide_text_icon_url = resource_path("gui_utilities/icons/focused_hide_text_icon.png"),
+    show_text_icon_url = resource_path("icons/show_text_icon.png"),
+    hide_text_icon_url = resource_path("icons/hide_text_icon.png"),
+    focused_show_text_icon_url = resource_path("icons/focused_show_text_icon.png"),
+    focused_hide_text_icon_url = resource_path("icons/focused_hide_text_icon.png"),
     hide_text = False,
     math_expression = False,
     parent = None
@@ -1326,7 +1326,7 @@ def validate_cellphone_number(cellphone_number):
     if len(clean_number) == 10: return None
     return "No ha ingresado un número telefónico válido."
 
-tlds_list_path = resource_path("gui_utilities/tlds/tlds_list.txt")
+tlds_list_path = resource_path("tlds/tlds_list.txt")
 
 def export_tlds(tlds_list):
     try:
